COST_FOR_3 = 150000000
COST_FOR_4 = 50000000
COST_FOR_5 = 5000000
COST_FOR_TRANSFER = 2000000
COST_FOR_RENEWAL = 5000000
RENEWAL_TIME = 86400*365
ASCII_LOWER_CASE_A = 97
ASCII_LOWER_CASE_Z = 122
ASCII_DIGIT_0 = 48
ASCII_DIGIT_9 = 57
APP_ID = 628095415
RELEASE_TIME = "2022-02-25T10:00:00"